@@ -8,19 +8,14 @@ use Doctrine\Common\DataFixtures\ReferenceRepository;
 use Doctrine\Common\EventSubscriber;
 use Doctrine\ODM\MongoDB\Event\LifecycleEventArgs;
 
-use function get_class;
-
 /**
  * Reference Listener populates identities for
  * stored references
  */
 final class MongoDBReferenceListener implements EventSubscriber
 {
-    private ReferenceRepository $referenceRepository;
-
-    public function __construct(ReferenceRepository $referenceRepository)
+    public function __construct(private ReferenceRepository $referenceRepository)
     {
-        $this->referenceRepository = $referenceRepository;
     }
 
     /**
@@ -48,7 +43,7 @@ final class MongoDBReferenceListener implements EventSubscriber
                 ->getUnitOfWork()
                 ->getDocumentIdentifier($object);
 
-            $this->referenceRepository->setReferenceIdentity($name, $identity, get_class($object));
+            $this->referenceRepository->setReferenceIdentity($name, $identity, $object::class);
         }
     }
 }
