@@ -6,25 +6,18 @@ namespace Doctrine\Tests\Common\DataFixtures\TestEntity;
 
 use Doctrine\ORM\Mapping as ORM;
 
-/** @ORM\Entity */
 #[ORM\Entity]
 class Role
 {
-    /**
-     * @ORM\Column(type="integer")
-     * @ORM\Id
-     * @ORM\GeneratedValue(strategy="IDENTITY")
-     */
     #[ORM\Column]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'IDENTITY')]
-    private ?int $id = null;
+    private int|null $id = null;
 
-    /** @ORM\Column(length=50) */
     #[ORM\Column(length: 50)]
-    private ?string $name = null;
+    private string|null $name = null;
 
-    public function getId(): ?int
+    public function getId(): int|null
     {
         return $this->id;
     }
@@ -34,7 +27,7 @@ class Role
         $this->name = $name;
     }
 
-    public function getName(): ?string
+    public function getName(): string|null
     {
         return $this->name;
     }
